@@ -662,7 +662,14 @@ lldpd_decode(struct lldpd *cfg, char *frame, int s,
 		free(oport);
 	}
 	if (ochassis) {
-		lldpd_move_chassis(ochassis, chassis);
+		if (port->p_ttl == 0) {
+			/* Shutdown LLDPDU is special. We do not want to replace
+			 * the chassis. Free the new chassis (which is mostly empty) */
+			log_debug("decode", "received a shutdown LLDPDU");
+			lldpd_chassis_cleanup(chassis, 1);
+		} else {
+			lldpd_move_chassis(ochassis, chassis);
+		}
 		chassis = ochassis;
 	} else {
 		/* Chassis not known, add it */
@@ -1001,6 +1008,8 @@ lldpd_dot3_power_pd_pse(struct lldpd_hardware *hardware)
 		    selected_port->p_power.allocated,
 		    hardware->h_lport.p_power.allocated);
 		hardware->h_lport.p_power.allocated = selected_port->p_power.allocated;
+		hardware->h_lport.p_power.allocated_a = selected_port->p_power.allocated_a;
+		hardware->h_lport.p_power.allocated_b = selected_port->p_power.allocated_b;
 		levent_schedule_pdu(hardware);
 	}
 
@@ -1853,9 +1862,10 @@ lldpd_main(int argc, char *argv[], char *envp[])
 	if (lldpcli)
 		cfg->g_config.c_paused = 1;
 	cfg->g_config.c_receiveonly = receiveonly;
-	cfg->g_config.c_tx_interval = LLDPD_TX_INTERVAL;
+	cfg->g_config.c_tx_interval = LLDPD_TX_INTERVAL * 1000;
 	cfg->g_config.c_tx_hold = LLDPD_TX_HOLD;
 	cfg->g_config.c_ttl = cfg->g_config.c_tx_interval * cfg->g_config.c_tx_hold;
+	cfg->g_config.c_ttl = (cfg->g_config.c_ttl + 999) / 1000;
 	cfg->g_config.c_max_neighbors = LLDPD_MAX_NEIGHBORS;
 #ifdef ENABLE_LLDPMED
 	cfg->g_config.c_enable_fast_start = enable_fast_start;
