@@ -349,6 +349,8 @@ _lldpctl_atom_set_atom_port(lldpctl_atom_t *atom, lldpctl_key_t key, lldpctl_ato
 		return NULL;
 	}
 
+	set.vlan_tx_enabled = -1;
+
 	switch (key) {
 	case lldpctl_k_port_id:
 		set.local_id = p->port->p_id;
@@ -359,6 +361,10 @@ _lldpctl_atom_set_atom_port(lldpctl_atom_t *atom, lldpctl_key_t key, lldpctl_ato
 	case lldpctl_k_port_status:
 		set.rxtx = LLDPD_RXTX_FROM_PORT(p->port);
 		break;
+	case lldpctl_k_port_vlan_tx:
+		set.vlan_tx_tag = p->port->p_vlan_tx_tag;
+		set.vlan_tx_enabled = p->port->p_vlan_tx_enabled;
+		break;
 #ifdef ENABLE_DOT3
 	case lldpctl_k_port_dot3_power:
 		if (value->type != atom_dot3_power) {
@@ -520,6 +526,13 @@ _lldpctl_atom_set_int_port(lldpctl_atom_t *atom, lldpctl_key_t key,
 			port->p_disable_rx = !LLDPD_RXTX_RXENABLED(value);
 			port->p_disable_tx = !LLDPD_RXTX_TXENABLED(value);
 			break;
+		case lldpctl_k_port_vlan_tx:
+			if (value > -1) {
+				port->p_vlan_tx_tag = value;
+				port->p_vlan_tx_enabled = 1;
+			} else
+				port->p_vlan_tx_enabled = 0;
+			break;
 		default:
 			SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
 			return NULL;
@@ -622,6 +635,8 @@ _lldpctl_atom_get_int_port(lldpctl_atom_t *atom, lldpctl_key_t key)
 		return port->p_id_subtype;
 	case lldpctl_k_port_hidden:
 		return port->p_hidden_in;
+	case lldpctl_k_port_vlan_tx:
+		return port->p_vlan_tx_enabled ? port->p_vlan_tx_tag : -1;
 #ifdef ENABLE_DOT3
 	case lldpctl_k_port_dot3_mfs:
 		if (port->p_mfs > 0)
